@@ -10,7 +10,6 @@ import torchvision
 import numpy as np
 import omegaconf
 import PIL
-from PIL import Image
 from omegaconf import OmegaConf
 from forks.taming_transformers.taming.models.vqgan import VQModel
 from bigotis.modeling_utils import ImageGenerator
@@ -37,11 +36,6 @@ class TamingDecoder(ImageGenerator):
         """
         super().__init__()
 
-        self.supported_loss_types = [
-            "cosine_similarity",
-            "spherical_distance",
-        ]
-
         if device is not None:
             self.device = device
 
@@ -133,7 +127,7 @@ class TamingDecoder(ImageGenerator):
 
         return model.eval()
 
-    def get_img_rec_from_z(
+    def get_img_from_latents(
         self,
         z_logits: torch.Tensor,
     ):
@@ -144,7 +138,7 @@ class TamingDecoder(ImageGenerator):
         return img_rec
 
     @staticmethod
-    def get_random_latent(
+    def get_random_latents(
         target_img_height,
         target_img_width,
         batch_size=1,
@@ -163,25 +157,10 @@ class TamingDecoder(ImageGenerator):
 
         return z_logits
 
-    def compute_loss(
+    def get_latents_from_img(
         self,
-        promtp,
-        z_logits,
-        return_rec_img: bool = True,
+        img: PIL.Image.Image,
     ):
-
-        if not return_rec_img:
-            return loss
-
-        else:
-            return loss, x_rec
-
-    def get_latent_from_image(
-        self,
-        img: PIL.Image,
-    ):
-        assert type(img) == PIL.Image, "image needs to be a PIL.Image"
-
         img = img.convert('RGB')
 
         img_tensor = torch.tensor(np.asarray(img)).to(
@@ -232,7 +211,7 @@ class TamingDecoder(ImageGenerator):
                 for the CLIP embeddings. Defaults to None.
             generation_cb (function, optional): if provided, the 
                 function is executed for every optimization step. The
-                inputs of this function will be:  loss, step, x_rec, z_logits and step
+                inputs of this function will be:  loss, step, rec_img, z_logits and step
             init_embed (torh.Tensor, optional): initial embedding 
                 From where to start the generation. Defaults to None.
 
@@ -254,12 +233,9 @@ class TamingDecoder(ImageGenerator):
             z_logits = init_embed.to(self.device)
 
         elif init_img_path is not None:
-            pil_img = Image.open(init_img_path)
-            pil_img = pil_img.convert('RGB')
+            init_img = self.load_img(init_img_path, )
+            init_img = init_img * 2 - 1
 
-            init_img = torch.tensor(np.asarray(pil_img)).to(
-                self.device).float()[None, :]
-            init_img = (init_img / 255.) * 2 - 1
             init_img = init_img.permute(0, 3, 1, 2)
 
             # clip_img_z_logits = self.get_clip_img_encodings(init_img)
@@ -272,7 +248,7 @@ class TamingDecoder(ImageGenerator):
             # img_z_logits = z.detach().clone()
 
         else:
-            z_logits = self.get_random_latent(
+            z_logits = self.get_random_latents(
                 target_img_height=target_img_size,
                 target_img_width=target_img_size,
                 batch_size=batch_size,
@@ -294,9 +270,9 @@ class TamingDecoder(ImageGenerator):
 
             z_logits_list.append(z_logits.detach().clone())
 
-            x_rec = self.get_img_rec_from_z(z_logits)
+            rec_img = self.get_img_from_latents(z_logits)
             x_rec_stacked = self.augment(
-                x_rec,
+                rec_img,
                 num_crops=num_augmentations,
                 target_img_width=target_img_size,
                 target_img_height=target_img_size,
@@ -316,7 +292,7 @@ class TamingDecoder(ImageGenerator):
             #                                           img_z_logits).mean()
             # if init_img is not None:
             #     loss += -10 * torch.cosine_similarity(
-            #         self.get_clip_img_encodings(x_rec), clip_img_z_logits).mean()
+            #         self.get_clip_img_encodings(rec_img), clip_img_z_logits).mean()
 
             logging.info(f"\nIteration {step} of {num_steps}")
             logging.info(f"Loss {round(float(loss.data), 2)}")
@@ -325,15 +301,16 @@ class TamingDecoder(ImageGenerator):
             loss.backward()
             optimizer.step()
 
-            x_rec_img = torchvision.transforms.ToPILImage(mode='RGB')(x_rec[0])
+            x_rec_img = torchvision.transforms.ToPILImage(mode='RGB')(
+                rec_img[0])
             gen_img_list.append(x_rec_img)
 
             if generation_cb is not None:
                 generation_cb(
                     loss=loss,
                     step=step,
-                    x_rec=x_rec,
-                    z_logits=z_logits,
+                    rec_img=rec_img,
+                    latents=z_logits,
                 )
 
             torch.cuda.empty_cache()
@@ -376,11 +353,11 @@ class TamingDecoder(ImageGenerator):
                 z_logits = weight * z_logits_2 + (1 - weight) * z_logits_1
 
                 z = self.vqgan_model.post_quant_conv(z_logits)
-                x_rec = self.vqgan_model.decoder(z)
-                x_rec = (x_rec.clip(-1, 1) + 1) / 2
+                rec_img = self.vqgan_model.decoder(z)
+                rec_img = (rec_img.clip(-1, 1) + 1) / 2
 
                 x_rec_img = torchvision.transforms.ToPILImage(mode='RGB')(
-                    x_rec[0])
+                    rec_img[0])
                 gen_img_list.append(x_rec_img)
 
                 torch.cuda.empty_cache()
@@ -390,14 +367,14 @@ class TamingDecoder(ImageGenerator):
     def zoom(
         self,
         prompt: str,
-        init_latent: torch.Tensor,
+        init_latents: torch.Tensor,
         lr: float = 0.008,
         num_generations: int = 64,
         num_zoom_interp_steps=2,
         num_zoom_train_steps=8,
         zoom_offset=4,
     ):
-        z_logits = init_latent.detach().clone()
+        z_logits = init_latents.detach().clone()
         z_logits = torch.nn.Parameter(z_logits)
 
         optimizer = torch.optim.AdamW(
@@ -414,13 +391,13 @@ class TamingDecoder(ImageGenerator):
 
             with torch.no_grad():
                 z = self.vqgan_model.post_quant_conv(z_logits)
-                x_rec = self.vqgan_model.decoder(z)
-                x_rec = (x_rec.clip(-1, 1) + 1) / 2
+                rec_img = self.vqgan_model.decoder(z)
+                rec_img = (rec_img.clip(-1, 1) + 1) / 2
 
-                x_rec_size = x_rec.shape[-1]
+                x_rec_size = rec_img.shape[-1]
 
-                x_rec_zoom = x_rec[:, :, zoom_offset:-zoom_offset,
-                                   zoom_offset:-zoom_offset]
+                x_rec_zoom = rec_img[:, :, zoom_offset:-zoom_offset,
+                                     zoom_offset:-zoom_offset]
                 x_rec_zoom = torch.nn.functional.interpolate(
                     x_rec_zoom,
                     (x_rec_size, x_rec_size),
@@ -436,12 +413,12 @@ class TamingDecoder(ImageGenerator):
             for zoom_train_step in range(num_zoom_train_steps):
                 loss = 0
                 z = self.vqgan_model.post_quant_conv(z_logits)
-                x_rec = self.vqgan_model.decoder(z)
-                x_rec = (x_rec.clip(-1, 1) + 1) / 2
+                rec_img = self.vqgan_model.decoder(z)
+                rec_img = (rec_img.clip(-1, 1) + 1) / 2
                 x_rec_stacked = self.augment(
-                    x_rec,
-                    x_rec.shape[1],
-                    x_rec.shape[2],
+                    rec_img,
+                    rec_img.shape[1],
+                    rec_img.shape[2],
                 )
 
                 loss += 10 * self.compute_clip_loss(x_rec_stacked, prompt)
@@ -453,7 +430,7 @@ class TamingDecoder(ImageGenerator):
                 loss.backward()
                 optimizer.step()
 
-            z_logits_1 = init_latent
+            z_logits_1 = init_latents
             z_logits_2 = z_logits
 
             for zoom_step in range(num_zoom_interp_steps):
@@ -462,21 +439,21 @@ class TamingDecoder(ImageGenerator):
 
                 with torch.no_grad():
                     z = self.vqgan_model.post_quant_conv(interp_logits)
-                    x_rec = self.vqgan_model.decoder(z)
-                    x_rec = (x_rec.clip(-1, 1) + 1) / 2
+                    rec_img = self.vqgan_model.decoder(z)
+                    rec_img = (rec_img.clip(-1, 1) + 1) / 2
 
                 x_rec_img = torchvision.transforms.ToPILImage(mode='RGB')(
-                    x_rec[0])
+                    rec_img[0])
                 gen_img_list.append(x_rec_img)
 
                 print("Adding img...")
                 os.makedirs("generations", exist_ok=True)
                 x_rec_img = torchvision.transforms.ToPILImage(mode='RGB')(
-                    x_rec[0])
+                    rec_img[0])
                 x_rec_img.save(
                     f"generations/{step}_{zoom_step}_{zoom_train_step}.jpg")
 
-            init_latent = z_logits.detach().clone()
+            init_latents = z_logits.detach().clone()
 
             torch.cuda.empty_cache()
 
@@ -496,16 +473,17 @@ if __name__ == '__main__':
 
     taming_decoder = TamingDecoder()
 
-    init_latent_path = f"./{prompt}_logits.pt"
-    if os.path.exists(init_latent_path):
-        init_latent = torch.load(init_latent_path).to('cuda')
+    init_latents_path = f"./{prompt}_logits.pt"
+    if os.path.exists(init_latents_path):
+        init_latents = torch.load(init_latents_path).to('cuda')
     else:
 
         def save_img_cb(**kwargs, ):
             step = kwargs["step"]
-            x_rec = kwargs["x_rec"]
+            rec_img = kwargs["rec_img"]
 
-            x_rec_img = torchvision.transforms.ToPILImage(mode='RGB')(x_rec[0])
+            x_rec_img = torchvision.transforms.ToPILImage(mode='RGB')(
+                rec_img[0])
             x_rec_img.save(f"{step}.jpg")
 
         gen_img_list, z_logits_list = taming_decoder.generate_from_prompt(
@@ -520,12 +498,12 @@ if __name__ == '__main__':
             generation_cb=save_img_cb,
         )
 
-        init_latent = z_logits_list[-1]
-        torch.save(init_latent, f'{prompt}_logits.pt')
+        init_latents = z_logits_list[-1]
+        torch.save(init_latents, f'{prompt}_logits.pt')
 
     gen_img_list, z_logits_list = taming_decoder.zoom(
         prompt,
-        init_latent=init_latent,
+        init_latents=init_latents,
     )
 
     # _gen_img_list, z_logits_list_ = taming_decoder.generate_from_prompt(
